@@ -3,15 +3,17 @@
 ( cd usr/bin ; rm -rf cc )
 ( cd usr/bin ; ln -sf gcc cc )
 ( cd usr/bin ; rm -rf gcc )
-( cd usr/bin ; ln -sf gcc-3.3.1 gcc )
-( cd usr/bin ; rm -rf i486-slackware-linux-gcc-3.3.1 )
-( cd usr/bin ; ln -sf gcc-3.3.1 i486-slackware-linux-gcc-3.3.1 )
+( cd usr/bin ; ln -sf gcc-3.3.4 gcc )
+( cd usr/bin ; rm -rf i486-slackware-linux-gcc-3.3.4 )
+( cd usr/bin ; ln -sf gcc-3.3.4 i486-slackware-linux-gcc-3.3.4 )
 ( cd usr/bin ; rm -rf i486-slackware-linux-gcc )
-( cd usr/bin ; ln -sf gcc-3.3.1 i486-slackware-linux-gcc )
+( cd usr/bin ; ln -sf gcc-3.3.4 i486-slackware-linux-gcc )
 ( cd usr/bin ; rm -rf i486-slackware-linux-gcj )
 ( cd usr/bin ; ln -sf gcj i486-slackware-linux-gcj )
 ( cd usr/lib ; rm -rf libffi.so )
 ( cd usr/lib ; ln -sf libffi-2.00-beta.so libffi.so )
+( cd usr/lib/gcc-lib/i486-slackware-linux/3.3.4/include ; rm -rf GL )
+( cd usr/lib/gcc-lib/i486-slackware-linux/3.3.4/include ; ln -sf root/usr/X11R6/include/GL GL )
 ( cd usr/lib ; rm -rf libgcc_s.so )
 ( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
 ( cd usr/man/man1 ; rm -rf cc.1.gz )
